package com.xinelu.manage.mapper.sysarea;

import com.xinelu.manage.domain.sysarea.SysArea;
import com.xinelu.manage.vo.sysarea.AreaInfoVO;
import com.xinelu.manage.vo.sysarea.ParentAreaVO;
import com.xinelu.manage.vo.sysarea.SysAreaVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 区域Mapper接口
 *
 * @author jihan
 * @date 2022-09-02
 */
public interface SysAreaMapper {

    /**
     * 查询区域
     *
     * @param id       区域主键
     * @param areaCode 区域
     * @return 区域
     */
    SysArea selectSysAreaById(@Param("id") Long id, @Param("areaCode") String areaCode);

    /**
     * 查询区域列表
     *
     * @param sysArea 区域
     * @return 区域集合
     */
    List<SysArea> selectSysAreaList(SysArea sysArea);

    /**
     * 新增区域
     *
     * @param sysArea 区域
     * @return 结果
     */
    int insertSysArea(SysArea sysArea);

    /**
     * 修改区域
     *
     * @param sysArea 区域
     * @return 结果
     */
    int updateSysArea(SysArea sysArea);

    /**
     * 删除区域
     *
     * @param id 区域主键
     * @return 结果
     */
    int deleteSysAreaById(Long id);

    /**
     * 批量删除区域
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSysAreaByIds(Long[] ids);

    /**
     * 根据区域编码查询对应得市级区域信息
     *
     * @param areaCode 区域编码
     * @return 市级区域集合
     */
    List<AreaInfoVO> getCityInfoList(@Param("areaCode") String areaCode, @Param("remoteSigns") Integer remoteSigns);

    /**
     * 根据父id查询街道信息集合
     *
     * @param parentIdList 父id集合
     * @return 街道集合
     */
    List<AreaInfoVO> getStreetInfoList(@Param("parentIdList") List<Long> parentIdList);

    /**
     * 下级区域寻找上级区域
     *
     * @param areaCode 区域编码
     * @return com.xinyilu.base.domain.vo.sysarea.SysAreaVO
     **/
    SysAreaVO getSubordinateRegionsFindSuperiorRegions(@Param("areaCode") String areaCode);

    /**
     * 区域编码的集合
     *
     * @param areaCodeList 区域编码的集合
     * @return java.util.List<com.xinyilu.base.domain.vo.sysarea.SysAreaVO>
     **/
    List<SysAreaVO> getNurseStationAreaByList(@Param("areaCodeList") List<String> areaCodeList);

    /**
     * 区域编码的
     *
     * @param areaCode 区域编码的集合
     * @return java.util.List<com.xinyilu.base.domain.vo.sysarea.SysAreaVO>
     **/
    SysAreaVO getNurseStationAreaByCode(@Param("areaCode") String areaCode);

    /**
     * 小程序商品修改用户地址地址区域编码的集合(街道)
     *
     * @param areaCodeList 区域编码的集合
     * @return java.util.List<com.xinyilu.base.domain.vo.sysarea.SysAreaVO>
     **/
    List<SysAreaVO> getNurseStationGoodsAreaByList(@Param("areaCodeList") List<String> areaCodeList);

    /**
     * 查询本级区域信息及上级区域信息
     *
     * @param id 区域主键
     * @return ParentAreaVO
     */
    ParentAreaVO selectParentName(Long id);
}
